pub enum CrsError {
Proj(Error),
Wkt(String),
}Expand description
Failure to build a Crs from a textual definition.
Variants
Proj(Error)
The proj4 / EPSG definition was rejected by proj4rs.
Wkt(String)
The WKT string could not be parsed to a proj definition.